.. _urls:

.. raw:: html

    <br>

.. title:: urls


.. raw:: html

    <center>

urls
====

.. raw:: html

    </center>
    <br>

.. _18procent:

18% van de opnames zijn vanwege de medicijnen.

https://www.pw.nl/archief/wp/2013wp02/a1308/at_download/file

.. _cohen:

leefstijlziektes

https://www.nrc.nl/nieuws/2018/04/06/stop-met-het-belonen-van-patienten-die-ongezond-leven-a1598487

.. _damage:

4% schade aan de hippocamus door Haldol

* https://jamanetwork.com/journals/jamapsychiatry/article-abstract/2672208


.. _sds:

Clozapine Safety Data Sheet

* https://drive.google.com/open?id=0BwaFXkZBje4OLTZ2ZEhmVWhZZmc

.. _highlights:

Clozapine Highlights of Prescribing Information

*  https://drive.google.com/open?id=0BwaFXkZBje4OdnBmS05sQ2dkUEE


GENEESMIDDELENBANK

* http://www.geneesmiddeleninformatiebank.nl/ords/f?p=111

GEBRUIK

* https://www.nza.nl/publicaties/1048188/Marktscan_en_beleidsbrief_GGZ_2012
  (pagina 19)

INFO

* https://vergiftigingen.info

CBG

* https://www.cbg-meb.nl/zoeken
* http://db.cbg-meb.nl/ords/f?p=111:search:0:::RP,1:P0_DOMAIN,P0_LANG,P1_SORT,P1_RESPPG:H,NL,PRODA,10


30 JAAR EERDER

* http://www.socialevraagstukken.nl/oplossing-voor-verwarde-personen-geen-taskforce-maar-een-betere-reguliere-ggz/

BIJWERKINGEN

* http://rxisk.org/side-effects-of-antipsychotics

GOTZSCHE 

* https://www.tweedekamer.nl/vergaderingen/commissievergaderingen/details?id=2016A01153

* https://www.wemos.nl/wp-content/uploads/2016/09/Gotzsche-Dutch-Parliament-29-March-2016.pdf

APENRECHT

* http://www.ncbi.nlm.nih.gov/pmc/articles/PMC3476840/

ZWARE LICHAMELIJK LETSEL

* http://uitspraken.rechtspraak.nl/inziendocument?id=ECLI:NL:HR:2001:AB0495

VAN OS GEEFT SCHADELIJKHEID TOE.

* https://www.psychosenet.nl/antipsychotica-en-dss/

DOPAMINE WERKING

* http://www.news-medical.net/health/Dopamine-Functions.aspx

ZYPREXA ONDERZOEK

* http://www.rug.nl/research/portal/publications/pub(7cd87f64-45e5-4b41-a90f-00e270ba1609).html

REGIONAAL TUCHTCOLLEGE VOOR DE GEZONDHEIDSZORG

* http://tuchtrecht.overheid.nl/zoeken/resultaat/uitspraak/2014/ECLI_NL_TGZRAMS_2014_94?zaaknummer=2013%2F221&Pagina=1&ItemIndex=1

Acute Geestelijke Gezondheidszorg: Knelpunten en verbetervoorstellen in de keten

* http://www.rijksoverheid.nl/documenten-en-publicaties/rapporten/2015/02/11/acute-geestelijke-gezondheidszorg-knelpunten-en-verbetervoorstellen-in-de-keten.html

F-ACT leid niet tot minder opnames

* http://mgv.boomtijdschriften.nl/artikelen/GV-67-6-319_Zorggebruik%20van%20patinten%20in%20ACT%20of%20FACT%20.html

"Hier vond men dat alleen in regio’s waar teams werkten met optimale 24-uursbereikbaarheid het aantal opnames met 20% verminderde en de opnameduur met 10% werd bekort. 
Regio’s met teams die deze 7*24 uur bereikbaarheid niet hadden georganiseerd, lieten geen reductie in aantal opnames of opnameduur zien."

* http://www.tijdschriftvoorpsychiatrie.nl/issues/434/articles/8318

24 uur per dag zorg in de nabijheid omdat hij zelf niet in staat is om op
relevante momenten hulp in te roepen

* http://www.psynip.nl/website-openbaar-themas/sector-gezondheidszorg/langdurige-zorg/2015035366-hhm-afwegingskader-concept-bestuurlijke-consultatie-1-povoopen.pdf

Antipsychotica resulteren in zenuwcellen sterfte

* http://www.ncbi.nlm.nih.gov/pmc/articles/PMC3476840/ 

Thematische wetsevalutatie Verplichte GGZ

* http://www.zonmw.nl/nl/publicaties/detail/thematische-wetsevaluatie-gedwongen-zorg/

Rapport van de onderzoekscommissie strafrechtelijke beslissingen openbaar ministerie (Commissie Hoekstra) naar aanleiding van de zaak-Bart van U.

* http://www.tweedekamer.nl/kamerstukken/brieven_regering/detail?id=2015Z12483&did=2015D25147

Omvang van het probleem

Jaarlijks zijn er rond de 24 000 mensen met ernstige psychiatrische problemen die geen
contact hebben met de hulpverlening. Ze zijn niet opgenomen en doen vaak ook geen
beroep op andere vormen van hulp.

Voor naar schatting 8000 van deze mensen is er daarbij sprake van geregeld optredende
acute nood, bijvoorbeeld door verergering van ziekteverschijnselen, zoals wanen
of hallucinaties, al dan niet in combinatie met verslavingsproblemen. Vaak hebben deze
patiënten ook grote sociale problemen, zoals geen onderdak en gebrek aan voedsel en
geld. Ze verzorgen zichzelf slecht en hebben vaak geen contact met familie.

Deze groep van naar schatting 8000 mensen krijgt of zoekt vaak niet de zorg die
hulpverleners, familieleden en andere betrokkenen noodzakelijk achten. Soms is er noodgedwongen 
sprake van overlast voor de omgeving. Maar mensen kunnen ook vereenzamen en verkommeren,
soms zichtbaar op straat, vaak zonder dat anderen dit waarnemen.

* http://www.gezondheidsraad.nl/sites/default/files/samenvatting_noodgedwongen_0.pdf

"Dit betekent dat met de WvGGZ veel meer ambulante dwang mogelijk wordt. "

* http://www.dsp-groep.nl/userfiles/file/Politie%20en%20verwarde%20personen%20_DSP-groep.pdf

"De commissie schrijft dat de regiebehandelaar verantwoordelijk is voor de integrale behandeling
(paragraaf 5.2 van het advies). Hij draagt echter niet de verantwoordelijkheid voor de door andere
zorgverleners tijdens het behandelingstraject uitgevoerde verrichtingen die zijn gelegen buiten
het terrein waarop hij zelf deskundig is."

* https://www.rijksoverheid.nl/documenten/kamerstukken/2015/09/01/beantwoording-kamervragen-over-advies-hoofdbehandelaarschap-ggz

Tweede nota van wijziging WvGGZ

* http://www.ypsilon.org/download/?id=18770429&download=1

* https://tekeertegendeisoleer.wordpress.com/2014/07/13/recente-activiteiten-en-reactie-op-tweede-nota-van-wijziging-wetsvoorstel-verplichte-ggz/

* https://tekeertegendeisoleer.files.wordpress.com/2014/07/reactie-mindrights_tweedenotavanwijziging-wvggz.pdf

* https://www.rijksoverheid.nl/binaries/rijksoverheid/documenten/kamerstukken/2015/03/31/kamerbrief-over-evaluatie-gedwongen-zorg-en-vertrouwenswerk/kamerbrief-over-evaluatie-gedwongen-zorg-en-vertrouwenswerk.pdf

* http://www.platformggz.nl/lpggz/download/wet-verplicht-ggz/wet.verplichte.ggz.hoorzitting.pdf

* http://www.ggznederland.nl/uploads/assets/Gezamenlijke%20Factsheet%20Wet%20verplichte%20GGZ%20-%202014.pdf

* http://netwerk-kjp.nl/data/uploads/naar-aanleiding-verslag-wet-verplichte-geestelijke-gezondheidszorg.pdf

* https://www.eerstekamer.nl/behandeling/20140325/nader_verslag/document3/f=/vjiciqay0pxn.pdf

* https://www.eerstekamer.nl/behandeling/20140206/advies_van_andere_adviesorganen/document3/f=/vjr5ino1g5y9.pdf

* https://www.eerstekamer.nl/behandeling/20130930/nota_van_wijziging/document3/f=/vjdqe7hcwf5n.pdf

F-ACT en minister

* https://www.rijksoverheid.nl/documenten/kamerstukken/2015/09/21/kamerbrief-over-situatie-forensische-f-act-teams?utm_source=twitterfeed&utm_medium=twitter

de Kabinetsreactie op de thematische wetsevaluatie over gedwongen zorg van ZonMw

* https://www.rijksoverheid.nl/binaries/rijksoverheid/documenten/rapporten/2014/09/01/thematische-wetsevaluatie-gedwongen-zorg/thematische-wetsevaluatie-gedwongen-zorg.pdf